@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd ;
-$Config::Model::Backend::Systemd::VERSION = '0.004';
+$Config::Model::Backend::Systemd::VERSION = '0.005';
 use strict;
 use warnings;
 use 5.010;
@@ -26,12 +26,6 @@ has config_dir => (
     isa => 'Path::Tiny'
 );
 
-sub config_file_override {
-    my $self = shift ;
-    my $basename = $self->node->index_value.'.'.$self->node->element_name;
-    return $self->config_dir->child($basename);
-}
-
 # TODO: accepts other systemd suffixes
 my $filter = qr/\.(service|socket)$/;
 
@@ -115,6 +109,10 @@ sub write {
 no Mouse ;
 __PACKAGE__->meta->make_immutable ;
 
+1;
+
+# ABSTRACT: R/W backend for systemd configurations files
+
 __END__
 
 =pod
@@ -123,11 +121,44 @@ __END__
 
 =head1 NAME
 
-Config::Model::Backend::Systemd
+Config::Model::Backend::Systemd - R/W backend for systemd configurations files
 
 =head1 VERSION
 
-version 0.004
+version 0.005
+
+=head1 SYNOPSIS
+
+ # in systemd model
+ read_config => [
+      {
+        'backend' => 'Systemd'
+      }
+    ]
+
+=head1 DESCRIPTION
+
+Config::Model::Backend::Systemd provides a plugin class to enable
+L<Config::Model> to read and write systemd configuration files. This
+class inherits L<Config::Model::Backend::Any> is designed to be used
+by L<Config::Model::BackendMgr>.
+
+=head1 Methods
+
+=head2 read
+
+This method scans systemd default directory and systemd config
+directory to create all units in L<Config::Model> tree. The actual
+configuration parameters are read by
+L<Config::Model::Backend::Systemd::Unit>.
+
+=head2 write
+
+This method is a bit of a misnomer. It deletes configuration files of
+deleted service.
+
+The actual configuration parameters are written by
+L<Config::Model::Backend::Systemd::Unit>.
 
 =head1 AUTHOR
 
