@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd::Layers;
-$Config::Model::Backend::Systemd::Layers::VERSION = '0.004';
+$Config::Model::Backend::Systemd::Layers::VERSION = '0.005';
 use Mouse::Role;
 
 
@@ -43,6 +43,8 @@ sub default_directories {
 
 1;
 
+# ABSTRACT: Role that provides Systemd default directories
+
 __END__
 
 =pod
@@ -51,11 +53,29 @@ __END__
 
 =head1 NAME
 
-Config::Model::Backend::Systemd::Layers
+Config::Model::Backend::Systemd::Layers - Role that provides Systemd default directories
 
 =head1 VERSION
 
-version 0.004
+version 0.005
+
+=head1 SYNOPSIS
+
+ package Config::Model::Backend::Systemd ;
+ extends 'Config::Model::Backend::Any';
+ with 'Config::Model::Backend::Systemd::Layers';
+
+=head1 DESCRIPTION
+
+Small role to provide Systemd default directories (user or system) to
+L<Config::Model::Backend::Systemd> and L<Config::Model::Backend::Systemd::Unit>.
+
+=head1 Methods
+
+=head2 default_directories
+
+Returns a list of default directory, depending on the application used (either
+C<systemd> or C<systemd-user>.
 
 =head1 AUTHOR
 
